==> haskell-network-control-0.0.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-A7JLcHSBoysDfO8iOF1OiT
key:                  network-control-0.0.2-A7JLcHSBoysDfO8iOF1OiT
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  fc12184c4da6c57be3b2797868981088
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-A7JLcHSBoysDfO8iOF1OiT
depends:
    base-4.17.2.1 psqueues-0.2.8.1-2MX8ieLdASiB2WHK2JtHN8
    unix-time-0.4.16-CxvWolV8N09AwIr3jcCLSx

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-control-0.0.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-IO9TiQ3tKAp3ucMOoMfS3m
key:                  network-control-0.0.2-IO9TiQ3tKAp3ucMOoMfS3m
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  f003e82c6999ee6c81c31dc803d2de6a
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-IO9TiQ3tKAp3ucMOoMfS3m
depends:
    base-4.17.2.1 psqueues-0.2.8.1-947qW91hRMRGP1E69UIY2O
    unix-time-0.4.16-JxYOC3zDCmgAXzO2iifixm

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
